<?php

namespace Drupal\idealyzer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class ApiConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['idealyzer.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'idealyzer_api_config_form';
  }

  /**
   * Builds the API configuration form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('idealyzer.settings');
    $apiKey = $config->get('api_key');
    $placeholder = !empty($apiKey) ? str_repeat('•', strlen($apiKey)) : '';

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $placeholder,  // Use the dynamically created placeholder
      '#description' => $this->t('Enter the API key for the GSA Site Scanning API. For security, the actual key is not displayed.'),
      '#required' => TRUE,
      '#attributes' => ['placeholder' => $placeholder],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Handles form submission.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $newApiKey = $form_state->getValue('api_key');
    $currentApiKey = $this->config('idealyzer.settings')->get('api_key');
    
    // Create a masked version of the current API key to compare with the submitted value
    $maskedCurrentApiKey = str_repeat('•', strlen($currentApiKey));

    // Check if the submitted API key is not just the masked placeholder
    if ($newApiKey !== $maskedCurrentApiKey) {
        // Save only if the new API key is different from the current, unmasked API key
        if ($newApiKey !== $currentApiKey) {
            $this->config('idealyzer.settings')
                 ->set('api_key', $newApiKey)
                 ->save();
            $this->messenger()->addMessage($this->t('API Key updated successfully.'));
        } else {
            $this->messenger()->addMessage($this->t('No change detected in the API Key.'));
        }
    } else {
        $this->messenger()->addMessage($this->t('No new API Key entered.'));
    }
}

}
